﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.ObjectModel;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Editors;
using Infragistics.Windows.DataPresenter.Events;


//http://forums.infragistics.com/forums/p/65964/333701.aspx

namespace InfragisticsDataEntryTest
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public BindingList<Person> People { get; set; }
        public List<String> Genders { get; set; }
        private bool IsEscKeyPressed;
        private Record NewRecord;

        public MainWindow()
        {
            InitializeComponent();
            CreateData();
            this.DataContext = this;
        }

        private void PeopleGrid_InitializeTemplateAddRecord(object sender, Infragistics.Windows.DataPresenter.Events.InitializeTemplateAddRecordEventArgs e)
        {
            e.TemplateAddRecord.Cells["Gender"].Value = Person.Genders.Male.ToString();  // Set default gender to male
            e.TemplateAddRecord.Cells["Name"].Value = "Sam";                            // Set default name to Sam
        }

        private void PeopleGrid_RecordUpdating(object sender, Infragistics.Windows.DataPresenter.Events.RecordUpdatingEventArgs e)
        {
            if (IsEscKeyPressed)
            {
                e.Record.CancelUpdate();
                IsEscKeyPressed = false;
                return;
            }

            // Data validation
            Person person = e.Record.DataItem as Person;
            
            if (String.IsNullOrEmpty(person.Name))
            {
                MessageBox.Show("Name cannot be blank.");
                e.Action = RecordUpdatingAction.CancelUpdateRetainChanges;
                CellValuePresenter.FromCell(e.Record.Cells[0]).StartEditMode();
            }

            // Write data to disk here

            if (e.Record == NewRecord)
            {
                Infragistics.Windows.DataPresenter.XamDataGrid dp = sender as Infragistics.Windows.DataPresenter.XamDataGrid;
                Dispatcher.BeginInvoke(new Action(() =>
                {
                    dp.ActiveRecord.RecordManager.CurrentAddRecord.Cells[0].IsActive = true;
                    dp.ExecuteCommand(DataPresenterCommands.StartEditMode);

                }), System.Windows.Threading.DispatcherPriority.Background, null);
                NewRecord = null;
            }
        }

        private void PeopleGrid_RecordUpdated(object sender, Infragistics.Windows.DataPresenter.Events.RecordUpdatedEventArgs e)
        {
            CellValuePresenter.FromCell(e.Record.Cells[0]).StartEditMode();
        }

        private void PeopleGrid_RecordsDeleting(object sender, Infragistics.Windows.DataPresenter.Events.RecordsDeletingEventArgs e)
        {
            foreach (Record r in e.Records)
            {
                Person p = (Person)((DataRecord)r).DataItem;
                // Delete here
            }
        }

        private void PeopleGrid_RecordAdded(object sender, RecordAddedEventArgs e)
        {
            NewRecord = e.Record;
        }

        private void XamDataGrid_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Escape)
                IsEscKeyPressed = true;
        }

        private void Gender_SelectedItemChanged(object sender, RoutedEventArgs e)
        {
            if (PeopleGrid.ActiveRecord == null || ((DataRecord)PeopleGrid.ActiveRecord).DataItem == null)
                return;

            Person person = (PeopleGrid.ActiveRecord as DataRecord).DataItem as Person;
            XamComboEditor cb = (XamComboEditor)e.OriginalSource;

            if (cb.SelectedItem.ToString() == Person.Genders.Male.ToString())
                person.Age = 40;
            else
                person.Age = 30;

            e.Handled = true;
        }


        private void Age_LostFocus(object sender, RoutedEventArgs e)
        {
        
        }

        private void CreateData()
        {
            People = new BindingList<Person>();
            People.Add(new Person { Name = "John Smith", Gender = Person.Genders.Male.ToString(), Age = 27 });
            People.Add(new Person { Name = "Jane Doe", Gender = Person.Genders.Female.ToString(), Age = 41 });

            Genders = new List<string>
            {
                "Male",
                "Female"
            };
        }
    }


    public class Person :INotifyPropertyChanged
    {
        public enum Genders
        {
            Male,
            Female
        }
        
        private string _Name;
        public string Name
        {
            get { return _Name; }
            set
            {
                if (_Name != value)
                {
                    _Name = value;
                    OnPropertyChanged("Name");
                }
            }
        }

        private string _Gender;
        public string Gender
        {
            get{ return _Gender;}
            set
            {
                if(_Gender != value)
                {
                    _Gender = value;
                    OnPropertyChanged("Gender");
                }
            }
        }

        private int _Age;
        public int Age
        {
            get{return _Age;}
            set
            {
                if(_Age != value)
                {
                    _Age = value;
                    OnPropertyChanged("Age");
                }
            }
        }


        #region INotifyPropertyChanged Members
        public event PropertyChangedEventHandler PropertyChanged;

        public void OnPropertyChanged(string name)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(name));
            }
        }
        #endregion

    }
}
